@@ -5,21 +5,25 @@ import logging
 
 from icalendar import Calendar, Event
 
-import json
-
-from django.db.models import Q
-from django.views.generic import TemplateView, View
+from django.conf import settings
+from django.contrib import messages
 from django.contrib.sites.shortcuts import get_current_site
 from django.core.exceptions import ObjectDoesNotExist, PermissionDenied
+from django.db.models import Q
 from django.http import HttpResponse, JsonResponse
 from django.utils import timezone
-from django.conf import settings
+from django.utils.dateparse import parse_datetime
+from django.utils.decorators import method_decorator
+from django.views.decorators.http import condition
+from django.views.generic import TemplateView, View
 
 from bakery.views import BuildableDetailView, BuildableTemplateView, BuildableMixin
 from rest_framework import viewsets
 from rest_framework.permissions import IsAdminUser
+from wafer import __version__
 from wafer.pages.models import Page
-from wafer.schedule.models import Venue, Slot, ScheduleBlock, ScheduleItem
+from wafer.schedule.models import (
+    Venue, Slot, ScheduleBlock, ScheduleItem, get_schedule_version)
 from wafer.schedule.admin import check_schedule, validate_schedule
 from wafer.schedule.serializers import ScheduleItemSerializer
 from wafer.talks.models import ACCEPTED, CANCELLED
@@ -145,12 +149,21 @@ def lookup_highlighted_venue(request):
     return None
 
 
+def schedule_version_last_modified(request, **kwargs):
+    """Return the current schedule version as a datetime"""
+    version = get_schedule_version()
+    return parse_datetime(version)
+
+
+@method_decorator(
+    condition(last_modified_func=schedule_version_last_modified),
+    name='dispatch')
 class ScheduleView(BuildableTemplateView):
     template_name = 'wafer.schedule/full_schedule.html'
     build_path = 'schedule/index.html'
 
     def get_context_data(self, **kwargs):
-        context = super(ScheduleView, self).get_context_data(**kwargs)
+        context = super().get_context_data(**kwargs)
         # Check if the schedule is valid
         context['active'] = False
         context['prev_block'] = None
@@ -182,6 +195,7 @@ class ScheduleView(BuildableTemplateView):
             if pos < len(blocks) - 1:
                 context['next_block'] = blocks[pos + 1]
         context['schedule_pages'] = generate_schedule(this_block)
+        context['schedule_version'] = get_schedule_version()
         return context
 
 
@@ -192,7 +206,10 @@ class ScheduleXmlView(ScheduleView):
 
     def get_context_data(self, **kwargs):
         """Allow adding a 'render_description' parameter"""
-        context = super(ScheduleXmlView, self).get_context_data(**kwargs)
+        context = super().get_context_data(**kwargs)
+        context['wafer_version'] = __version__
+        context['TIME_ZONE'] = settings.TIME_ZONE
+        context['WAFER_CONFERENCE_ACRONYM'] = settings.WAFER_CONFERENCE_ACRONYM
         if self.request.GET.get('render_description', None) == '1':
             context['render_description'] = True
         else:
@@ -203,31 +220,31 @@ class ScheduleXmlView(ScheduleView):
 class CurrentView(TemplateView):
     template_name = 'wafer.schedule/current.html'
 
-    def _parse_today(self, day):
-        if day is None:
-            day = datetime.date.today()
-        else:
-            day = datetime.datetime.strptime(day, '%Y-%m-%d').date()
+    def _parse_timestamp(self, timestamp):
+        """
+        Parse a user provided timestamp query string parameter.
+        Return a TZ aware datetime, or None.
+        """
+        if not timestamp:
+            return None
+        try:
+            timestamp = parse_datetime(timestamp)
+        except ValueError as e:
+            messages.error(self.request,
+                           'Failed to parse timestamp: %s' % e)
+        if timestamp is None:
+            messages.error(self.request, 'Failed to parse timestamp')
+            return None
+        if not timezone.is_aware(timestamp):
+            timestamp = timezone.make_aware(timestamp)
+        return timestamp
+
+    def _get_schedule_page(self, timestamp):
         for candidate in ScheduleBlock.objects.all():
-            if candidate.start_time.date() <= day and candidate.end_time.date() >= day:
+            if candidate.start_time < timestamp < candidate.end_time:
                 return SchedulePage(candidate)
         return None
 
-    def _parse_time(self, day, time):
-        tz = timezone.get_default_timezone()
-        now = timezone.make_aware(datetime.datetime.now(), tz)
-        if day is None:
-            return now
-        if time is None:
-            return now
-        try:
-            full_time = datetime.datetime.combine(datetime.datetime.strptime(day, "%Y-%m-%d").date(),
-                                                  datetime.datetime.strptime(time, '%H:%M').time())
-            return timezone.make_aware(full_time, tz)
-        except ValueError:
-            pass
-        return now
-
     def _add_note(self, row, note, overlap_note):
         for item in row.items.values():
             if item['rowspan'] == 1:
@@ -274,7 +291,7 @@ class CurrentView(TemplateView):
         return [r for r in rows if r]
 
     def get_context_data(self, **kwargs):
-        context = super(CurrentView, self).get_context_data(**kwargs)
+        context = super().get_context_data(**kwargs)
         # If the schedule is invalid, return a context with active=False
         context['active'] = False
         if not check_schedule():
@@ -284,20 +301,23 @@ class CurrentView(TemplateView):
         context['slots'] = []
         # Allow refresh time to be overridden
         context['refresh'] = self.request.GET.get('refresh', None)
+
+        # Allow the current time to be overridden, mostly for testing
+        timestamp = self._parse_timestamp(
+                self.request.GET.get('timestamp', None)) or timezone.now()
+
+        schedule_page = self._get_schedule_page(timestamp)
         # If there are no items scheduled for today, return an empty slots list
-        schedule_page = self._parse_today(self.request.GET.get('day', None))
         if schedule_page is None:
             return context
         context['schedule_page'] = schedule_page
-        # Allow current time to be overridden
-        time = self._parse_time(self.request.GET.get('day', None), self.request.GET.get('time', None))
 
         highlight_venue = lookup_highlighted_venue(self.request)
         context['highlight_venue_pk'] = -1
         if highlight_venue is not None:
             context['highlight_venue_pk'] = highlight_venue
 
-        cur_slot, current_rows = self._current_slots(schedule_page, time)
+        cur_slot, current_rows = self._current_slots(schedule_page, timestamp)
         context['cur_slot'] = cur_slot
         context['slots'].extend(current_rows)
 
@@ -345,7 +365,7 @@ class ScheduleEditView(TemplateView):
         return slot_context
 
     def get_context_data(self, block_id=None, **kwargs):
-        context = super(ScheduleEditView, self).get_context_data(**kwargs)
+        context = super().get_context_data(**kwargs)
 
         blocks = ScheduleBlock.objects.all()
         if block_id:
@@ -379,6 +399,9 @@ class ScheduleEditView(TemplateView):
         return context
 
 
+@method_decorator(
+    condition(last_modified_func=schedule_version_last_modified),
+    name='dispatch')
 class ICalView(View, BuildableMixin):
     build_path = 'schedule/schedule.ics'
 
@@ -427,6 +450,9 @@ class ICalView(View, BuildableMixin):
         self.build_file(path, self.get_content())
 
 
+@method_decorator(
+    condition(last_modified_func=schedule_version_last_modified),
+    name='dispatch')
 class JsonDataView(View, BuildableMixin):
     build_path = "schedule/schedule.json"
 
