@@ -50,7 +50,7 @@ class SponsorshipPackage(models.Model):
     symbol = models.CharField(
         max_length=1, blank=True,
         help_text=_("Optional symbol to display in the sponsors list "
-                    "next to sponsors who have sponsored at this list, "
+                    "next to sponsors who have taken this package, "
                     "(for example *)."))
 
     class Meta:
@@ -73,7 +73,7 @@ class Sponsor(models.Model):
         help_text=_("Write some nice things about the sponsor."))
     url = models.URLField(
         default="", blank=True,
-        help_text=_("Url to link back to the sponsor if required"))
+        help_text=_("URL to link back to the sponsor if required"))
 
     class Meta:
         ordering = ['order', 'name', 'id']
