@@ -7,6 +7,7 @@ from django.contrib.auth.models import User, Group
 from django.db import models
 from django.db.models import Q
 from django.db.models.signals import post_save
+from django.dispatch import receiver
 from django.utils.module_loading import import_string
 from django.utils.translation import ugettext_lazy as _
 from django.core.validators import RegexValidator
@@ -28,7 +29,6 @@ from wafer.talks.models import (ACCEPTED, SUBMITTED, UNDER_CONSIDERATION,
 # Specification taken from https://support.twitter.com/articles/101299
 TwitterValidator = RegexValidator('^[A-Za-z0-9_]{1,15}$',
                                   'Incorrectly formatted twitter handle')
-is_registered = import_string(settings.WAFER_USER_IS_REGISTERED)
 
 
 class UserProfile(models.Model):
@@ -95,11 +95,13 @@ class UserProfile(models.Model):
         return self.user.get_full_name() or self.user.username
 
     def is_registered(self):
+        is_registered = import_string(settings.WAFER_USER_IS_REGISTERED)
         return is_registered(self.user)
 
     is_registered.boolean = True
 
 
+@receiver(post_save, sender=User)
 def create_user_profile(sender, instance, created, raw=False, **kwargs):
     if raw:
         return
@@ -107,6 +109,7 @@ def create_user_profile(sender, instance, created, raw=False, **kwargs):
         UserProfile.objects.create(user=instance)
 
 
+@receiver(post_save, sender=User)
 def add_default_groups(sender, instance, created, raw=False, **kwargs):
     """Add the user to the configured set of default groups"""
     if raw:
@@ -118,7 +121,3 @@ def add_default_groups(sender, instance, created, raw=False, **kwargs):
                 instance.groups.add(group)
             except ObjectDoesNotExist:
                 logger.warn("Specified default group %s not found" % grp_name)
-
-
-post_save.connect(create_user_profile, sender=User)
-post_save.connect(add_default_groups, sender=User)
